@@ -1,5 +1,5 @@
 /* idn.c --- Command line interface to libidn.
- * Copyright (C) 2003-2022 Simon Josefsson
+ * Copyright (C) 2003-2024 Simon Josefsson
  *
  * This file is part of GNU Libidn.
  *
@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -48,9 +48,9 @@
 #include "idn_cmd.h"
 
 #define GREETING \
-  "Copyright 2002-2022 Simon Josefsson.\n"				 \
+  "Copyright 2002-2024 Simon Josefsson.\n"				 \
   "GNU Libidn is free software with ABSOLUTELY NO WARRANTY.  For more\n" \
-  "information about these matters, see <http://www.gnu.org/licenses/>.\n"
+  "information about these matters, see <https://www.gnu.org/licenses/>.\n"
 
 const char version_etc_copyright[] =
   /* Do *not* mark this string for translation.  %s is a copyright
@@ -189,7 +189,11 @@ main (int argc, char *argv[])
   do
     {
       if (cmdn < args_info.inputs_num)
-	line = strdup (args_info.inputs[cmdn++]);
+	{
+	  line = strdup (args_info.inputs[cmdn++]);
+	  if (!line)
+	    error (EXIT_FAILURE, errno, N_("strdup"));
+	}
       else if (getline (&line, &linelen, stdin) == -1)
 	{
 	  if (feof (stdin))
