@@ -1,5 +1,5 @@
 /* tst_idna.c --- Self tests for idna_to_ascii().
- * Copyright (C) 2002-2022 Simon Josefsson
+ * Copyright (C) 2002-2024 Simon Josefsson
  *
  * This file is part of GNU Libidn.
  *
@@ -284,7 +284,7 @@ doit (void)
       if (debug)
 	{
 	  printf ("expected out (%lu):\n",
-		  rc == IDNA_SUCCESS ? idna[i].inlen : len);
+		  (unsigned long) (rc == IDNA_SUCCESS ? idna[i].inlen : len));
 	  if (rc == IDNA_SUCCESS)
 	    ucs4print (idna[i].in, idna[i].inlen);
 	  else
